@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::Author::IOANR;
-$Dist::Zilla::PluginBundle::Author::IOANR::VERSION = '0.005';
+$Dist::Zilla::PluginBundle::Author::IOANR::VERSION = '0.006';
 # ABSTRACT: Build dists the way IOANR likes
 use v5.12;
 use Moose;
@@ -49,7 +49,7 @@ sub _build_release_plugins {
 
     return [
         'ConfirmRelease',
-        ['Git::Commit' => {allow_dirty => [qw/README.mkdn dist.ini Changes/]}],
+        ['Git::Commit' => {allow_dirty => [qw/README.md dist.ini Changes LICENSE/]}],
         [
             'Git::CommitBuild' => {
                 branch               => '',
@@ -58,8 +58,8 @@ sub _build_release_plugins {
                 multiple_inheritance => 1,
             }
         ],
-        'Git::Push',
         ['Git::Tag' => {signed => 1, branch => 'release'}],
+        'Git::Push',
         'GitHub::Update',
         'UploadToCPAN',
     ];
@@ -101,6 +101,7 @@ sub configure {
         [
             'Git::Check' => {
                 allow_dirty     => [qw/README.md dist.ini Changes LICENSE/],
+                build_warnings  => 1,
                 untracked_files => 'warn',
             }
         ],
@@ -185,7 +186,7 @@ Dist::Zilla::PluginBundle::Author::IOANR - Build dists the way IOANR likes
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
@@ -296,7 +297,7 @@ web interface at L<https://github.com/ioanrogers/Dist-Zilla-PluginBundle-Author-
 
 =head1 AVAILABILITY
 
-The project homepage is L<http://metacpan.org/release/Dist-Zilla-PluginBundle-Author-IOANR/>.
+The project homepage is L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-Author-IOANR/>.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
